@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Stats.py
-Version : 1.0.0
+Version : 1.0.1
 Author  : Stefano Covino
-Date    : 19/02/2012
+Date    : 27/03/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -13,6 +13,7 @@ Usage   : to be imported
 Remarks : input is a list of (x,sigmax)
 
 History : (19/02/2012) First version.
+        : (27/03/2013) Output in case of single entry.
 
 """
 
@@ -22,6 +23,8 @@ from scipy.stats import scoreatpercentile
 
 
 def ScoreatPercentile(vl, percdown=31.7, percc=50.0, percup=68.3):
+    if len(vl) == 1:
+        return list(vl)[0],list(vl)[0],list(vl)[0],0.0
     if SS.stdev(list(vl)) != 0.0:
         vd = scoreatpercentile(list(vl),percdown)
         vc = scoreatpercentile(list(vl),percc)    
