@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Statistics
-Version : 1.4.0
+Version : 1.5.0
 Author  : Stefano Covino
-Date    : 04/04/2013
+Date    : 07/06/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -19,11 +19,13 @@ History : (28/10/2010) First version.
         : (27/08/2012) Faster sigma clipping for frames.
         : (04/03/2013) MAD.
         : (04/04/2013) XCorr_1D.
+        : (07/06/2013) FTest.
 """
 
 
 
 __all__ = ['AsymmetricGaussianDistrib', 'AverIterSigmaClipp', 'AverSigmaClippFrame', 
-           'AverSigmaClippFrameFast', 'ChSqIncrement', 'CoordDistanceMinimization', 'GenFitPars',
-           'GenGaussSet', 'MAD', 'ScoreatPercentile', 'XCorr_1D', 'WeightedMean', 'WeightedMeanFrame']
+           'AverSigmaClippFrameFast', 'ChSqIncrement', 'CoordDistanceMinimization', 'FTest',
+           'GenFitPars', 'GenGaussSet', 'MAD', 'ScoreatPercentile', 'XCorr_1D', 'WeightedMean',
+           'WeightedMeanFrame']
 
