@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.1.13
+Version : 1.1.18
 Author  : Stefano Covino
-Date    : 19/04/2013
+Date    : 12/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -92,6 +92,11 @@ History : (28/09/2010) First named version.
         : (03/04/2013) V. 3.10.9b3.
         : (18/04/2013) V. 3.10.9b4.
         : (19/04/2013) V. 3.10.9.
+        : (06/05/2013) V. 3.10.10b1.
+        : (07/06/2013) V. 3.10.10b2.
+        : (26/07/2013) APASS catalogue and V. 3.10.10.b3.
+        : (29/07/2013) GetTabEntry returns not identified objects too and V. 3.10.10.b4.
+        : (12/08/2013) V. 3.10.10.
 """
 
 
@@ -106,5 +111,5 @@ __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhot
 
 
 # Version
-__version__ = '3.10.9'
+__version__ = '3.10.10'
 
